package
Version:
v0.0.0-...-487cccc
Opens a new window with list of versions in this module.
Published: Sep 1, 2024
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
-
func Filter[T any](s []T, f func(T) bool) []T
-
func ForEach[T any](s []T, f func(T))
-
func Map[T, U any](s []T, f func(T) U) []U
-
func Reduce[T any, U any](s []T, f func(U, T) U, init U) U
-
func ToMap[K comparable, T, V any](s []T, f func(T) (K, V)) map[K]V
func Filter[T any](s []T, f func(T) bool) []T
func ForEach[T any](s []T, f func(T))
func Map[T, U any](s []T, f func(T) U) []U
func Reduce[T any, U any](s []T, f func(U, T) U, init U) U
func ToMap[K comparable, T, V any](s []T, f func(T) (K, V)) map[K]V
Source Files
¶
Click to show internal directories.
Click to hide internal directories.