package
Version:
v0.0.0-...-487cccc
Opens a new window with list of versions in this module.
Published: Sep 1, 2024
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Choice[T any](cond bool, tv, fv T) T
func Lazy[T any](cond bool, v T, onFalse func() T) T
Lazy returns trueValue if condition is true, otherwise it returns the result of falseValue.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.