package
Version:
v0.0.0-...-487cccc
Opens a new window with list of versions in this module.
Published: Sep 1, 2024
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func SetMaxGoroutines(maxGoroutines int)
type Execution[T any] func() option.Option[T]
type Future[T any] interface {
Await() option.Option[T]
}
Future is a type that represents a value that will be available in the onceFuture.
Async creates a new onceFuture with the given fn function.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.