package
Version:
v0.0.0-...-487cccc
Opens a new window with list of versions in this module.
Published: Sep 1, 2024
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func From[T any](p *T, onNil T) T
Source Files
¶
Click to show internal directories.
Click to hide internal directories.